@@ -1,4 +1,4 @@
-__version__ = "0.16.0"
+__version__ = "0.17.0"
 
 from e3nn_jax._src.config import config
 from e3nn_jax._src.rotation import (
@@ -67,13 +67,14 @@ from e3nn_jax._src.tensor_products import (
 from e3nn_jax._src.grad import grad
 from e3nn_jax._src.activation import scalar_activation, normalize_function
 from e3nn_jax._src.gate import gate
-from e3nn_jax._src.graph_util import index_add, radius_graph, scatter_sum
+from e3nn_jax._src.radius_graph import radius_graph
+from e3nn_jax._src.scatter import index_add, scatter_sum, scatter_max
 from e3nn_jax._src.reduced_tensor_product import (
     reduced_tensor_product_basis,
     reduced_symmetric_tensor_product_basis,
     reduced_antisymmetric_tensor_product_basis,
 )
-from e3nn_jax._src.s2grid import s2_irreps, to_s2grid, to_s2point, from_s2grid, s2_sum_of_diracs, SphericalSignal
+from e3nn_jax._src.s2grid import s2_irreps, to_s2grid, to_s2point, from_s2grid, s2_dirac, SphericalSignal
 
 # make submodules flax and haiku available
 from e3nn_jax import flax, haiku
@@ -156,9 +157,10 @@ __all__ = [
     "scalar_activation",
     "normalize_function",
     "gate",
-    "index_add",
     "radius_graph",
+    "index_add",
     "scatter_sum",
+    "scatter_max",
     "poly_envelope",
     "soft_envelope",
     "reduced_tensor_product_basis",
@@ -168,7 +170,7 @@ __all__ = [
     "to_s2grid",
     "to_s2point",
     "from_s2grid",
-    "s2_sum_of_diracs",
+    "s2_dirac",
     "SphericalSignal",
     "flax",
     "haiku",
