@@ -9,6 +9,8 @@ import jax.scipy
 
 from e3nn_jax import generators, matrix_to_angles, perm, quaternion_to_angles
 
+from .J import Jd
+
 IntoIrrep = Union[int, "Irrep", "MulIrrep", Tuple[int, int]]
 
 
@@ -492,7 +494,7 @@ class Irreps(tuple):
     def __mul__(self, other):
         r"""Multiply the multiplicities of the irreps.
 
-        Example:
+        Examples:
             >>> Irreps('0e + 1e') * 2
             2x0e+2x1e
         """
@@ -503,7 +505,7 @@ class Irreps(tuple):
     def __rmul__(self, other):
         r"""Multiply the multiplicities of the irreps.
 
-        Example:
+        Examples:
             >>> 2 * Irreps('0e + 1e')
             2x0e+2x1e
         """
@@ -512,7 +514,7 @@ class Irreps(tuple):
     def __floordiv__(self, other):
         r"""Divide the multiplicities of the irreps.
 
-        Example:
+        Examples:
             >>> Irreps('12x0e + 14x1e') // 2
             6x0e+7x1e
         """
@@ -534,7 +536,7 @@ class Irreps(tuple):
     def repeat(self, n: int) -> "Irreps":
         r"""Repeat the representation ``n`` times.
 
-        Example:
+        Examples:
             >>> Irreps('0e + 1e').repeat(2)
             1x0e+1x1e+1x0e+1x1e
         """
@@ -598,9 +600,11 @@ class Irreps(tuple):
         r"""Sort the representations.
 
         Returns:
-            irreps (`Irreps`): sorted irreps
-            p (tuple of int): permutation of the indices
-            inv (tuple of int): inverse permutation of the indices
+            (tuple): tuple containing:
+
+                irreps (`Irreps`): sorted irreps
+                p (tuple of int): permutation of the indices
+                inv (tuple of int): inverse permutation of the indices
 
         Examples:
             >>> Irreps("1e + 0e + 1e").sort().irreps
@@ -722,7 +726,7 @@ class Irreps(tuple):
     def dim(self) -> int:
         r"""Dimension of the irreps.
 
-        Example:
+        Examples:
             >>> Irreps("3x0e + 2x1e").dim
             9
         """
@@ -732,7 +736,7 @@ class Irreps(tuple):
     def num_irreps(self) -> int:
         """Sum of the multiplicities.
 
-        Example:
+        Examples:
             >>> Irreps("3x0e + 2x1e").num_irreps
             5
         """
@@ -742,7 +746,7 @@ class Irreps(tuple):
     def ls(self) -> List[int]:
         """List of the l values.
 
-        Example:
+        Examples:
             >>> Irreps("3x0e + 2x1e").ls
             [0, 0, 0, 1, 1]
         """
@@ -752,7 +756,7 @@ class Irreps(tuple):
     def lmax(self) -> int:
         """Maximum l value.
 
-        Example:
+        Examples:
             >>> Irreps("3x0e + 2x1e").lmax
             1
         """
@@ -927,10 +931,23 @@ def _wigner_D_from_angles(l: int, alpha: jnp.ndarray, beta: jnp.ndarray, gamma:
     alpha = alpha % (2 * jnp.pi)
     beta = beta % (2 * jnp.pi)
     gamma = gamma % (2 * jnp.pi)
-    X = generators(l)
 
     def f(a, b, c):
-        return jax.scipy.linalg.expm(a * X[1]) @ jax.scipy.linalg.expm(b * X[0]) @ jax.scipy.linalg.expm(c * X[1])
+        def rot_y(phi):
+            M = jnp.zeros((2 * l + 1, 2 * l + 1), dtype=phi.dtype)
+            inds = jnp.arange(0, 2 * l + 1, 1)
+            reversed_inds = jnp.arange(2 * l, -1, -1)
+            frequencies = jnp.arange(l, -l - 1, -1.0, dtype=phi.dtype)
+            M = M.at[inds, reversed_inds].set(jnp.sin(frequencies * phi))
+            M = M.at[inds, inds].set(jnp.cos(frequencies * phi))
+            return M
+
+        if l < len(Jd):
+            J = Jd[l]
+            return rot_y(a) @ J @ rot_y(b) @ J @ rot_y(c)
+        else:
+            X = generators(l)
+            return jax.scipy.linalg.expm(a * X[1]) @ jax.scipy.linalg.expm(b * X[0]) @ jax.scipy.linalg.expm(c * X[1])
 
     return _naive_broadcast_decorator(f)(alpha, beta, gamma)
 
